@@ -1,9 +1,12 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML;
 
 use PDO;
 use PDOException;
+use PDOStatement;
 
 /**
  * This file implements functions to read and write to a group of database servers.
@@ -76,7 +79,7 @@ class Database
      *
      * @param \SimpleSAML\Configuration $config Instance of the \SimpleSAML\Configuration class
      */
-    private function __construct($config)
+    private function __construct(Configuration $config)
     {
         $driverOptions = $config->getArray('database.driver_options', []);
         if ($config->getBoolean('database.persistent', true)) {
@@ -116,7 +119,7 @@ class Database
      *
      * @return string $instanceId
      */
-    private static function generateInstanceId($config)
+    private static function generateInstanceId(Configuration $config): string
     {
         $assembledConfig = [
             'master' => [
@@ -137,14 +140,14 @@ class Database
      * This function connects to a database.
      *
      * @param string $dsn Database connection string
-     * @param string $username SQL user
-     * @param string $password SQL password
+     * @param string|null $username SQL user
+     * @param string|null $password SQL password
      * @param array  $options PDO options
      *
      * @throws \Exception If an error happens while trying to connect to the database.
      * @return \PDO object
      */
-    private function connect($dsn, $username, $password, $options)
+    private function connect(string $dsn, string $username = null, string $password = null, array $options): PDO
     {
         try {
             $db = new PDO($dsn, $username, $password, $options);
@@ -163,7 +166,7 @@ class Database
      *
      * @return \PDO object
      */
-    private function getSlave()
+    private function getSlave(): PDO
     {
         if (count($this->dbSlaves) > 0) {
             $slaveId = rand(0, count($this->dbSlaves) - 1);
@@ -197,12 +200,8 @@ class Database
      * @throws \Exception If an error happens while trying to execute the query.
      * @return \PDOStatement object
      */
-    private function query($db, $stmt, $params)
+    private function query(PDO $db, string $stmt, array $params): PDOStatement
     {
-        assert(is_object($db));
-        assert(is_string($stmt));
-        assert(is_array($params));
-
         try {
             $query = $db->prepare($stmt);
 
@@ -233,11 +232,8 @@ class Database
      * @throws \Exception If an error happens while trying to execute the query.
      * @return int The number of rows affected.
      */
-    private function exec($db, $stmt)
+    private function exec(PDO $db, string $stmt): int
     {
-        assert(is_object($db));
-        assert(is_string($stmt));
-
         try {
             return $db->exec($stmt);
         } catch (PDOException $e) {
@@ -260,8 +256,7 @@ class Database
         $db = $this->dbMaster;
 
         if (is_array($params)) {
-            $obj = $this->query($db, $stmt, $params);
-            return ($obj === false) ? $obj : $obj->rowCount();
+            return $this->query($db, $stmt, $params)->rowCount();
         } else {
             return $this->exec($db, $stmt);
         }
