@@ -1,10 +1,13 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Error;
 
 use SimpleSAML\Configuration;
 use SimpleSAML\Logger;
 use SimpleSAML\Utils;
+use Throwable;
 
 /**
  * This exception represents a configuration error that we cannot recover from.
@@ -64,11 +67,11 @@ class CriticalConfigurationError extends ConfigurationError
 
 
     /**
-     * @param \Exception $exception
+     * @param \Throwable $exception
      *
-     * @return CriticalConfigurationError
+     * @return \SimpleSAML\Error\Exception
      */
-    public static function fromException(\Exception $exception)
+    public static function fromException(Throwable $exception): Exception
     {
         $reason = null;
         $file = null;
