@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Metadata;
 
 use SimpleSAML\Error;
@@ -183,7 +185,7 @@ abstract class MetaDataStorageSource
 
         foreach ($metadataSet as $index => $entry) {
             $cidrHints = [];
-            
+
             // support hint.cidr for idp discovery
             if (array_key_exists('hint.cidr', $entry) && is_array($entry['hint.cidr'])) {
                 $cidrHints = $entry['hint.cidr'];
@@ -298,7 +300,6 @@ abstract class MetaDataStorageSource
     protected function lookupIndexFromEntityId($entityId, array $metadataSet)
     {
         assert(is_string($entityId));
-        assert(is_array($metadataSet));
 
         // check for hostname
         $currentHost = Utils\HTTP::getSelfHost(); // sp.example.org
@@ -324,10 +325,8 @@ abstract class MetaDataStorageSource
      * @throws \Exception
      * @return string
      */
-    private function getDynamicHostedUrl($set)
+    private function getDynamicHostedUrl(string $set): string
     {
-        assert(is_string($set));
-
         // get the configuration
         $baseUrl = Utils\HTTP::getBaseURL();
 
@@ -362,7 +361,6 @@ abstract class MetaDataStorageSource
     {
         assert(is_string($metadataSet));
         assert(is_string($entityId));
-        assert(is_array($metadataEntry));
 
         $modifiedMetadataEntry = $metadataEntry;
 
