@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Utils;
 
 use PHPMailer\PHPMailer\PHPMailer;
@@ -71,7 +73,7 @@ class EMail
         return $address;
     }
 
-    
+
     /**
      * Set the data that should be embedded in the e-mail body
      *
@@ -158,8 +160,6 @@ class EMail
     public function setTransportMethod($transportMethod, array $transportOptions = [])
     {
         assert(is_string($transportMethod));
-        assert(is_array($transportOptions));
-
 
         switch (strtolower($transportMethod)) {
             // smtp transport method
@@ -231,8 +231,6 @@ class EMail
      */
     public static function initFromConfig(EMail $EMail)
     {
-        assert($EMail instanceof EMail);
-
         $config = Configuration::getInstance();
         $EMail->setTransportMethod(
             $config->getString('mail.transport.method', 'mail'),
