@@ -2,6 +2,13 @@
 
 namespace SimpleSAML\Module\authorize\Auth\Process;
 
+use SimpleSAML\Auth\State;
+use SimpleSAML\Module;
+use SimpleSAML\Utils\Arrays;
+use SimpleSAML\Utils\HTTP;
+use SimpleSAML\Module\Authorize\Tests\Utils;
+use Webmozart\Assert\Assert;
+
 /**
  * Filter to authorize only certain users.
  * See docs directory.
@@ -53,36 +60,35 @@ class Authorize extends \SimpleSAML\Auth\ProcessingFilter
 
         assert(is_array($config));
 
-        // Check for the deny option, get it and remove it
-        // Must be bool specifically, if not, it might be for a attrib filter below
+        // Check for the deny option
+        // Must be bool specifically, if not, it might be for an attrib filter below
         if (isset($config['deny']) && is_bool($config['deny'])) {
             $this->deny = $config['deny'];
-            unset($config['deny']);
         }
 
-        // Check for the regex option, get it and remove it
-        // Must be bool specifically, if not, it might be for a attrib filter below
+        // Check for the regex option
+        // Must be bool specifically, if not, it might be for an attrib filter below
         if (isset($config['regex']) && is_bool($config['regex'])) {
             $this->regex = $config['regex'];
-            unset($config['regex']);
         }
 
-        // Check for the reject_msg option, get it and remove it
-        // Must be array of languages
+        // Check for the reject_msg option; Must be array of languages
         if (isset($config['reject_msg']) && is_array($config['reject_msg'])) {
             $this->reject_msg = $config['reject_msg'];
-            unset($config['reject_msg']);
         }
 
+        // Remove all above options
+        unset($config['deny'], $config['regex'], $config['reject_msg']);
+
         foreach ($config as $attribute => $values) {
             if (is_string($values)) {
-                $values = [$values];
-            }
-            if (!is_array($values)) {
+                $values = Arrays::arrayize($values);
+            } else if (!is_array($values)) {
                 throw new \Exception(
                     'Filter Authorize: Attribute values is neither string nor array: '.var_export($attribute, true)
                 );
             }
+
             foreach ($values as $value) {
                 if (!is_string($value)) {
                     throw new \Exception(
@@ -99,26 +105,24 @@ class Authorize extends \SimpleSAML\Auth\ProcessingFilter
      * Apply filter to validate attributes.
      *
      * @param array &$request  The current request
+     * @return void
      */
     public function process(&$request)
     {
-        $authorize = $this->deny;
         assert(is_array($request));
         assert(array_key_exists('Attributes', $request));
 
+        $authorize = $this->deny;
         $attributes = &$request['Attributes'];
         // Store the rejection message array in the $request
-        if(!empty($this->reject_msg)) {
+        if (!empty($this->reject_msg)) {
             $request['authprocAuthorize_reject_msg'] = $this->reject_msg;
         }
 
         foreach ($this->valid_attribute_values as $name => $patterns) {
             if (array_key_exists($name, $attributes)) {
                 foreach ($patterns as $pattern) {
-                    $values = $attributes[$name];
-                    if (!is_array($values)) {
-                        $values = [$values];
-                    }
+                    $values = Arrays::arrayize($attributes[$name]);
                     foreach ($values as $value) {
                         if ($this->regex) {
                             $matched = preg_match($pattern, $value);
@@ -149,12 +153,13 @@ class Authorize extends \SimpleSAML\Auth\ProcessingFilter
      * permission logic.
      *
      * @param array $request
+     * @return void
      */
-    protected function unauthorized(&$request)
+    protected function unauthorized(array &$request)
     {
         // Save state and redirect to 403 page
-        $id = \SimpleSAML\Auth\State::saveState($request, 'authorize:Authorize');
-        $url = \SimpleSAML\Module::getModuleURL('authorize/authorize_403.php');
-        \SimpleSAML\Utils\HTTP::redirectTrustedURL($url, ['StateId' => $id]);
+        $id = State::saveState($request, 'authorize:Authorize');
+        $url = Module::getModuleURL('authorize/authorize_403.php');
+        HTTP::redirectTrustedURL($url, ['StateId' => $id]);
     }
 }
