@@ -1,5 +1,7 @@
 <?php
 
+namespace SimpleSAML\Module\sqlauth\Auth\Source;
+
 /**
  * Simple SQL authentication source
  *
@@ -9,7 +11,7 @@
  * @package SimpleSAMLphp
  */
 
-class sspmod_sqlauth_Auth_Source_SQL extends sspmod_core_Auth_UserPassBase
+class SQL extends \SimpleSAML\Module\core\Auth\UserPassBase
 {
     /**
      * The DSN we should connect to.
@@ -53,16 +55,16 @@ class sspmod_sqlauth_Auth_Source_SQL extends sspmod_core_Auth_UserPassBase
         parent::__construct($info, $config);
 
         // Make sure that all required parameters are present.
-        foreach (array('dsn', 'username', 'password', 'query') as $param) {
+        foreach (['dsn', 'username', 'password', 'query'] as $param) {
             if (!array_key_exists($param, $config)) {
-                throw new Exception('Missing required attribute \'' . $param .
-                    '\' for authentication source ' . $this->authId);
+                throw new \Exception('Missing required attribute \''.$param.
+                    '\' for authentication source '.$this->authId);
             }
 
             if (!is_string($config[$param])) {
-                throw new Exception('Expected parameter \'' . $param .
-                    '\' for authentication source ' . $this->authId .
-                    ' to be a string. Instead it was: ' .
+                throw new \Exception('Expected parameter \''.$param.
+                    '\' for authentication source '.$this->authId.
+                    ' to be a string. Instead it was: '.
                     var_export($config[$param], true));
             }
         }
@@ -80,32 +82,32 @@ class sspmod_sqlauth_Auth_Source_SQL extends sspmod_core_Auth_UserPassBase
     /**
      * Create a database connection.
      *
-     * @return PDO  The database connection.
+     * @return \PDO  The database connection.
      */
     private function connect()
     {
         try {
-            $db = new PDO($this->dsn, $this->username, $this->password, $this->options);
-        } catch (PDOException $e) {
-            throw new Exception('sqlauth:' . $this->authId . ': - Failed to connect to \'' .
-                $this->dsn . '\': '. $e->getMessage());
+            $db = new \PDO($this->dsn, $this->username, $this->password, $this->options);
+        } catch (\PDOException $e) {
+            throw new \Exception('sqlauth:'.$this->authId.': - Failed to connect to \''.
+                $this->dsn.'\': '.$e->getMessage());
         }
 
-        $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
+        $db->setAttribute(\PDO::ATTR_ERRMODE, \PDO::ERRMODE_EXCEPTION);
 
         $driver = explode(':', $this->dsn, 2);
         $driver = strtolower($driver[0]);
 
-        /* Driver specific initialization. */
+        // Driver specific initialization
         switch ($driver) {
-        case 'mysql':
-            /* Use UTF-8. */
-            $db->exec("SET NAMES 'utf8mb4'");
-            break;
-        case 'pgsql':
-            /* Use UTF-8. */
-            $db->exec("SET NAMES 'UTF8'");
-            break;
+            case 'mysql':
+                // Use UTF-8
+                $db->exec("SET NAMES 'utf8mb4'");
+                break;
+            case 'pgsql':
+                // Use UTF-8
+                $db->exec("SET NAMES 'UTF8'");
+                break;
         }
 
         return $db;
@@ -117,7 +119,7 @@ class sspmod_sqlauth_Auth_Source_SQL extends sspmod_core_Auth_UserPassBase
      *
      * On a successful login, this function should return the users attributes. On failure,
      * it should throw an exception. If the error was caused by the user entering the wrong
-     * username or password, a SimpleSAML_Error_Error('WRONGUSERPASS') should be thrown.
+     * username or password, a \SimpleSAML\Error\Error('WRONGUSERPASS') should be thrown.
      *
      * Note that both the username and the password are UTF-8 encoded.
      *
@@ -134,55 +136,54 @@ class sspmod_sqlauth_Auth_Source_SQL extends sspmod_core_Auth_UserPassBase
 
         try {
             $sth = $db->prepare($this->query);
-        } catch (PDOException $e) {
-            throw new Exception('sqlauth:' . $this->authId .
-                ': - Failed to prepare query: ' . $e->getMessage());
+        } catch (\PDOException $e) {
+            throw new \Exception('sqlauth:'.$this->authId.
+                ': - Failed to prepare query: '.$e->getMessage());
         }
 
         try {
-            $sth->execute(array('username' => $username, 'password' => $password));
-        } catch (PDOException $e) {
-            throw new Exception('sqlauth:' . $this->authId .
-                ': - Failed to execute query: ' . $e->getMessage());
+            $sth->execute(['username' => $username, 'password' => $password]);
+        } catch (\PDOException $e) {
+            throw new \Exception('sqlauth:'.$this->authId.
+                ': - Failed to execute query: '.$e->getMessage());
         }
 
         try {
-            $data = $sth->fetchAll(PDO::FETCH_ASSOC);
-        } catch (PDOException $e) {
-            throw new Exception('sqlauth:' . $this->authId .
-                ': - Failed to fetch result set: ' . $e->getMessage());
+            $data = $sth->fetchAll(\PDO::FETCH_ASSOC);
+        } catch (\PDOException $e) {
+            throw new \Exception('sqlauth:'.$this->authId.
+                ': - Failed to fetch result set: '.$e->getMessage());
         }
 
-        SimpleSAML\Logger::info('sqlauth:' . $this->authId . ': Got ' . count($data) .
+        \SimpleSAML\Logger::info('sqlauth:'.$this->authId.': Got '.count($data).
             ' rows from database');
 
         if (count($data) === 0) {
-            /* No rows returned - invalid username/password. */
-            SimpleSAML\Logger::error('sqlauth:' . $this->authId .
+            // No rows returned - invalid username/password
+            \SimpleSAML\Logger::error('sqlauth:'.$this->authId.
                 ': No rows in result set. Probably wrong username/password.');
-            throw new SimpleSAML_Error_Error('WRONGUSERPASS');
+            throw new \SimpleSAML\Error\Error('WRONGUSERPASS');
         }
 
         /* Extract attributes. We allow the resultset to consist of multiple rows. Attributes
          * which are present in more than one row will become multivalued. null values and
          * duplicate values will be skipped. All values will be converted to strings.
          */
-        $attributes = array();
+        $attributes = [];
         foreach ($data as $row) {
             foreach ($row as $name => $value) {
-
                 if ($value === null) {
                     continue;
                 }
 
-                $value = (string)$value;
+                $value = (string) $value;
 
                 if (!array_key_exists($name, $attributes)) {
-                    $attributes[$name] = array();
+                    $attributes[$name] = [];
                 }
 
                 if (in_array($value, $attributes[$name], true)) {
-                    /* Value already exists in attribute. */
+                    // Value already exists in attribute
                     continue;
                 }
 
@@ -190,7 +191,7 @@ class sspmod_sqlauth_Auth_Source_SQL extends sspmod_core_Auth_UserPassBase
             }
         }
 
-        SimpleSAML\Logger::info('sqlauth:' . $this->authId . ': Attributes: ' .
+        \SimpleSAML\Logger::info('sqlauth:'.$this->authId.': Attributes: '.
             implode(',', array_keys($attributes)));
 
         return $attributes;
