@@ -1,8 +1,10 @@
 <?php
+
 /**
  * Hook to do sanity checks
  *
  * @param array &$hookinfo  hookinfo
+ * @return void
  */
 function statistics_hook_sanitycheck(&$hookinfo)
 {
@@ -13,7 +15,7 @@ function statistics_hook_sanitycheck(&$hookinfo)
     try {
         $statconfig = \SimpleSAML\Configuration::getConfig('module_statistics.php');
     } catch (Exception $e) {
-        $hookinfo['errors'][] = '[statistics] Could not get configuration: '.$e->getMessage();
+        $hookinfo['errors'][] = '[statistics] Could not get configuration: ' . $e->getMessage();
         return;
     }
 
@@ -21,19 +23,19 @@ function statistics_hook_sanitycheck(&$hookinfo)
     $inputfile = $statconfig->getValue('inputfile');
 
     if (file_exists($statdir)) {
-        $hookinfo['info'][] = '[statistics] Statistics dir ['.$statdir.'] exists';
+        $hookinfo['info'][] = '[statistics] Statistics dir [' . $statdir . '] exists';
         if (is_writable($statdir)) {
-            $hookinfo['info'][] = '[statistics] Statistics dir ['.$statdir.'] is writable';
+            $hookinfo['info'][] = '[statistics] Statistics dir [' . $statdir . '] is writable';
         } else {
-            $hookinfo['errors'][] = '[statistics] Statistics dir ['.$statdir.'] is not writable';
+            $hookinfo['errors'][] = '[statistics] Statistics dir [' . $statdir . '] is not writable';
         }
     } else {
-        $hookinfo['errors'][] = '[statistics] Statistics dir ['.$statdir.'] does not exists';
+        $hookinfo['errors'][] = '[statistics] Statistics dir [' . $statdir . '] does not exist';
     }
 
     if (file_exists($inputfile)) {
-        $hookinfo['info'][] = '[statistics] Input file ['.$inputfile.'] exists';
+        $hookinfo['info'][] = '[statistics] Input file [' . $inputfile . '] exists';
     } else {
-        $hookinfo['errors'][] = '[statistics] Input file ['.$inputfile.'] does not exists';
+        $hookinfo['errors'][] = '[statistics] Input file [' . $inputfile . '] does not exist';
     }
 }
