@@ -2,24 +2,32 @@
 
 namespace SimpleSAML\Module\statistics\Statistics\Rulesets;
 
-/*
+use SimpleSAML\Configuration;
+use SimpleSAML\Module\statistics\RatioDataset;
+
+/**
  * @author Andreas Åkre Solberg <andreas.solberg@uninett.no>
  * @package SimpleSAMLphp
  */
-
 class Ratio extends BaseRule
 {
+    /** @var \SimpleSAML\Module\statistics\Statistics\Rulesets\BaseRule $refrule1 */
     protected $refrule1;
+
+    /** @var \SimpleSAML\Module\statistics\Statistics\Rulesets\BaseRule $refrule2 */
     protected $refrule2;
 
+
     /**
      * Constructor
+     *
+     * @param \SimpleSAML\Configuration $statconfig
+     * @param \SimpleSAML\Configuration $ruleconfig
+     * @param string $ruleid
+     * @param array $available
      */
-    public function __construct($statconfig, $ruleconfig, $ruleid, $available)
+    public function __construct(Configuration $statconfig, Configuration $ruleconfig, $ruleid, array $available)
     {
-        assert($statconfig instanceof \SimpleSAML\Configuration);
-        assert($ruleconfig instanceof \SimpleSAML\Configuration);
-
         parent::__construct($statconfig, $ruleconfig, $ruleid, $available);
 
         $refNames = $this->ruleconfig->getArray('ref');
@@ -33,31 +41,63 @@ class Ratio extends BaseRule
         $this->refrule2 = new BaseRule($this->statconfig, $statruleConfig2, $refNames[1], $available);
     }
 
+
+    /**
+     * @return array
+     */
     public function availableTimeRes()
     {
         return $this->refrule1->availableTimeRes();
     }
 
+
+    /**
+     * @param string $timeres
+     * @return array
+     */
     public function availableFileSlots($timeres)
     {
         return $this->refrule1->availableFileSlots($timeres);
     }
 
+
+    /**
+     * @param string $preferTimeRes
+     * @return string
+     */
     protected function resolveTimeRes($preferTimeRes)
     {
         return $this->refrule1->resolveTimeRes($preferTimeRes);
     }
 
+
+    /**
+     * @param string $timeres
+     * @param string $preferTime
+     * @return int
+     */
     protected function resolveFileSlot($timeres, $preferTime)
     {
         return $this->refrule1->resolveFileSlot($timeres, $preferTime);
     }
 
+
+    /**
+     * @param string $timeres
+     * @param string $preferTime
+     * @return array
+     */
     public function getTimeNavigation($timeres, $preferTime)
     {
         return $this->refrule1->getTimeNavigation($timeres, $preferTime);
     }
 
+
+    /**
+     * @param string $preferTimeRes
+     * @param string $preferTime
+     * @return \SimpleSAML\Module\statistics\RatioDataset
+     */
     public function getDataSet($preferTimeRes, $preferTime)
     {
         $timeres = $this->resolveTimeRes($preferTimeRes);
@@ -65,7 +105,7 @@ class Ratio extends BaseRule
 
         $refNames = $this->ruleconfig->getArray('ref');
 
-        $dataset = new \SimpleSAML\Module\statistics\RatioDataset(
+        $dataset = new RatioDataset(
             $this->statconfig,
             $this->ruleconfig,
             $refNames,
