@@ -1,7 +1,7 @@
 import "es6-shim";
 import ClipboardJS from "clipboard/dist/clipboard";
 import "selectize/dist/js/selectize";
-import hljs from  "highlight.js/lib/highlight";
+import hljs from  "highlight.js/lib/core";
 import xml from "highlight.js/lib/languages/xml";
 import php from "highlight.js/lib/languages/php";
 import json from "highlight.js/lib/languages/json";
