@@ -4,9 +4,8 @@
 <head>
     <meta http-equiv="content-type" content="text/html; charset=utf-8" />
     <title>POST data</title>
-    <script type="text/javascript" src="/<?php echo $this->data['baseurlpath']; ?>resources/post.js"></script>
-    <link 
-        type="text/css" rel="stylesheet" href="/<?php echo $this->data['baseurlpath']; ?>resources/post.css" />
+    <script src="/<?php echo $this->data['baseurlpath']; ?>resources/post.js"></script>
+    <link type="text/css" rel="stylesheet" href="/<?php echo $this->data['baseurlpath']; ?>resources/post.css" />
 </head>
 <body>
 
@@ -31,10 +30,10 @@ if (array_key_exists('post', $this->data)) {
     assert(array_key_exists('response', $this->data));
     assert(array_key_exists('RelayStateName', $this->data));
     assert(array_key_exists('RelayState', $this->data));
-        $post = array(
+        $post = [
         'SAMLResponse' => $this->data['response'],
         $this->data['RelayStateName'] => $this->data['RelayState'],
-    );
+        ];
 }
 
 /**
@@ -47,18 +46,19 @@ if (array_key_exists('post', $this->data)) {
  * @param string $name  The name of the element.
  * @param string|array $value  The value of the element.
  */
-function printItem($name, $value) {
+function printItem($name, $value)
+{
     assert(is_string($name));
     assert(is_string($value) || is_array($value));
     if (is_string($value)) {
-        echo '<input type="hidden" name="' . 
-            htmlspecialchars($name) . '" value="' . 
-            htmlspecialchars($value) . '" />';
+        echo '<input type="hidden" name="'.
+            htmlspecialchars($name).'" value="'.
+            htmlspecialchars($value).'" />';
         return;
     }
     // This is an array...
     foreach ($value as $index => $item) {
-        printItem($name . '[' . $index . ']', $item);
+        printItem($name.'['.$index.']', $item);
     }
 }
 
@@ -66,7 +66,6 @@ foreach ($post as $name => $value) {
     printItem($name, $value);
 }
 ?>
-
         <noscript>
             <button type="submit" class="btn">Submit</button>
         </noscript>
