@@ -1,7 +1,12 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\Utils;
 
+use SimpleSAML\Configuration;
+use SimpleSAML\Error;
+
 /**
  * Test that ensures state doesn't spill over between tests
  * @package SimpleSAML\Test\Utils
@@ -12,11 +17,11 @@ class ReduceSpillOverTest extends ClearStateTestCase
      * Set some global state
      * @return void
      */
-    public function testSetState()
+    public function testSetState(): void
     {
         $_SERVER['QUERY_STRING'] = 'a=b';
-        \SimpleSAML\Configuration::loadFromArray(['a' => 'b'], '[ARRAY]', 'simplesaml');
-        $this->assertEquals('b', \SimpleSAML\Configuration::getInstance()->getString('a'));
+        Configuration::loadFromArray(['a' => 'b'], '[ARRAY]', 'simplesaml');
+        $this->assertEquals('b', Configuration::getInstance()->getString('a'));
         putenv('SIMPLESAMLPHP_CONFIG_DIR=' . __DIR__);
     }
 
@@ -26,16 +31,16 @@ class ReduceSpillOverTest extends ClearStateTestCase
      * @return void
      * @throws \SimpleSAML\Error\ConfigurationError
      */
-    public function testStateRemoved()
+    public function testStateRemoved(): void
     {
         $this->assertArrayNotHasKey('QUERY_STRING', $_SERVER);
         /** @var false $env */
         $env = getenv('SIMPLESAMLPHP_CONFIG_DIR');
         $this->assertFalse($env);
         try {
-            \SimpleSAML\Configuration::getInstance();
+            Configuration::getInstance();
             $this->fail('Expected config configured in other tests to no longer be valid');
-        } catch (\SimpleSAML\Error\ConfigurationError $error) {
+        } catch (Error\ConfigurationError $error) {
             // Expected error
         }
     }
