@@ -1,8 +1,14 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\Utils;
 
+use InvalidArgumentException;
 use PHPUnit\Framework\TestCase;
+use ReflectionProperty;
+use SimpleSAML\Configuration;
+use SimpleSAML\Error;
 use SimpleSAML\Utils\Time;
 
 class TimeTest extends TestCase
@@ -13,7 +19,7 @@ class TimeTest extends TestCase
      * @covers SimpleSAML\Utils\Time::generateTimestamp
      * @return void
      */
-    public function testGenerateTimestamp()
+    public function testGenerateTimestamp(): void
     {
         // make sure passed timestamps are used
         $this->assertEquals('2016-03-03T14:48:05Z', Time::generateTimestamp(1457016485));
@@ -29,7 +35,7 @@ class TimeTest extends TestCase
      * @covers SimpleSAML\Utils\Time::initTimezone
      * @return void
      */
-    public function testInitTimezone()
+    public function testInitTimezone(): void
     {
         $tz = 'UTC';
         $os = @date_default_timezone_get();
@@ -38,31 +44,31 @@ class TimeTest extends TestCase
         }
 
         // test guessing timezone from the OS
-        \SimpleSAML\Configuration::loadFromArray(['timezone' => null], '[ARRAY]', 'simplesaml');
+        Configuration::loadFromArray(['timezone' => null], '[ARRAY]', 'simplesaml');
         @Time::initTimezone();
         $this->assertEquals($os, @date_default_timezone_get());
 
         // clear initialization
-        $c = new \ReflectionProperty('\SimpleSAML\Utils\Time', 'tz_initialized');
+        $c = new ReflectionProperty('\SimpleSAML\Utils\Time', 'tz_initialized');
         $c->setAccessible(true);
         $c->setValue(false);
 
         // test unknown timezone
-        \SimpleSAML\Configuration::loadFromArray(['timezone' => 'INVALID'], '[ARRAY]', 'simplesaml');
+        Configuration::loadFromArray(['timezone' => 'INVALID'], '[ARRAY]', 'simplesaml');
         try {
             @Time::initTimezone();
             $this->fail('Failed to recognize an invalid timezone.');
-        } catch (\SimpleSAML\Error\Exception $e) {
+        } catch (Error\Exception $e) {
             $this->assertEquals('Invalid timezone set in the "timezone" option in config.php.', $e->getMessage());
         }
 
         // test a valid timezone
-        \SimpleSAML\Configuration::loadFromArray(['timezone' => $tz], '[ARRAY]', 'simplesaml');
+        Configuration::loadFromArray(['timezone' => $tz], '[ARRAY]', 'simplesaml');
         @Time::initTimezone();
         $this->assertEquals($tz, @date_default_timezone_get());
 
         // make sure initialization happens only once
-        \SimpleSAML\Configuration::loadFromArray(['timezone' => 'Europe/Madrid'], '[ARRAY]', 'simplesaml');
+        Configuration::loadFromArray(['timezone' => 'Europe/Madrid'], '[ARRAY]', 'simplesaml');
         @Time::initTimezone();
         $this->assertEquals($tz, @date_default_timezone_get());
     }
@@ -74,7 +80,7 @@ class TimeTest extends TestCase
      * @covers SimpleSAML\Utils\Time::parseDuration
      * @return void
      */
-    public function testParseDuration()
+    public function testParseDuration(): void
     {
         // set up base date and time, and fixed durations from there
         $base = gmmktime(0, 0, 0, 1, 1, 2000);
@@ -165,14 +171,14 @@ class TimeTest extends TestCase
             // invalid string
             Time::parseDuration('abcdefg');
             $this->fail("Did not fail with invalid ISO 8601 duration.");
-        } catch (\InvalidArgumentException $e) {
+        } catch (InvalidArgumentException $e) {
             $this->assertStringStartsWith('Invalid ISO 8601 duration: ', $e->getMessage());
         }
         try {
             // missing T delimiter
             Time::parseDuration('P1S');
             $this->fail("Did not fail with duration missing T delimiter.");
-        } catch (\InvalidArgumentException $e) {
+        } catch (InvalidArgumentException $e) {
             $this->assertStringStartsWith('Invalid ISO 8601 duration: ', $e->getMessage());
         }
     }
