@@ -1,7 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\XML;
 
+use LibXMLError;
 use PHPUnit\Framework\TestCase;
 use SimpleSAML\XML\Errors;
 
@@ -23,7 +26,7 @@ class ErrorsTest extends TestCase
      * @test
      * @return void
      */
-    public function loggingErrors()
+    public function loggingErrors(): void
     {
         Errors::begin();
         $xmlstr = "<Test>Test</test>";
@@ -44,9 +47,9 @@ class ErrorsTest extends TestCase
      * @test
      * @return void
      */
-    public function formatErrors()
+    public function formatErrors(): void
     {
-        $error = new \LibXMLError();
+        $error = new LibXMLError();
         $error->level = 3;
         $error->code = 76;
         $error->line = 1;
