@@ -1,8 +1,13 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\Module\core\Auth\Process;
 
+use Exception;
 use PHPUnit\Framework\TestCase;
+use SimpleSAML\Configuration;
+use SimpleSAML\Module\core\Auth\Process\AttributeLimit;
 
 /**
  * Test for the core:AttributeLimit filter.
@@ -23,9 +28,9 @@ class AttributeLimitTest extends TestCase
      * @param array $request  The request state.
      * @return array  The state array after processing.
      */
-    private static function processFilter(array $config, array $request)
+    private static function processFilter(array $config, array $request): array
     {
-        $filter = new \SimpleSAML\Module\core\Auth\Process\AttributeLimit($config, null);
+        $filter = new AttributeLimit($config, null);
         $filter->process($request);
         return $request;
     }
@@ -35,7 +40,7 @@ class AttributeLimitTest extends TestCase
      * Test reading IdP Attributes.
      * @return void
      */
-    public function testIdPAttrs()
+    public function testIdPAttrs(): void
     {
         $config = [
             'cn', 'mail'
@@ -82,7 +87,7 @@ class AttributeLimitTest extends TestCase
      * Tests when no attributes are in metadata.
      * @return void
      */
-    public function testNULLMetadataAttrs()
+    public function testNULLMetadataAttrs(): void
     {
         $config = [
             'cn', 'mail'
@@ -160,7 +165,7 @@ class AttributeLimitTest extends TestCase
      * Test the most basic functionality.
      * @return void
      */
-    public function testBasic()
+    public function testBasic(): void
     {
         $config = [
             'cn', 'mail'
@@ -178,7 +183,7 @@ class AttributeLimitTest extends TestCase
      * Test defaults with metadata available.
      * @return void
      */
-    public function testDefaultWithMetadata()
+    public function testDefaultWithMetadata(): void
     {
         $config = [
             'default' => true,
@@ -196,7 +201,7 @@ class AttributeLimitTest extends TestCase
      * Test defaults with attributes and metadata
      * @return void
      */
-    public function testDefaultWithAttrs()
+    public function testDefaultWithAttrs(): void
     {
         $config = [
             'default' => true,
@@ -217,9 +222,9 @@ class AttributeLimitTest extends TestCase
      * Test for exception with illegal config.
      * @return void
      */
-    public function testInvalidConfig()
+    public function testInvalidConfig(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         $config = [
             'invalidArg' => true,
         ];
@@ -232,9 +237,9 @@ class AttributeLimitTest extends TestCase
      * Test for invalid attribute name
      * @return void
      */
-    public function testInvalidAttributeName()
+    public function testInvalidAttributeName(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         $config = [
             null
         ];
@@ -247,7 +252,7 @@ class AttributeLimitTest extends TestCase
      * Test for attribute value matching
      * @return void
      */
-    public function testMatchAttributeValues()
+    public function testMatchAttributeValues(): void
     {
         $config = [
             'eduPersonAffiliation' => ['member']
@@ -288,7 +293,7 @@ class AttributeLimitTest extends TestCase
     /**
      * @return void
      */
-    public function testBadOptionsNotTreatedAsValidValues()
+    public function testBadOptionsNotTreatedAsValidValues(): void
     {
         // Ensure really misconfigured ignoreCase and regex options are not interpretted as valid valus
         $config = [
@@ -306,7 +311,7 @@ class AttributeLimitTest extends TestCase
      * php and matched against an attribute value of '1'
      * @return void
      */
-    public function testThatIgnoreCaseOptionNotMatchBooleanAsStringValue()
+    public function testThatIgnoreCaseOptionNotMatchBooleanAsStringValue(): void
     {
         $config = [
             'someAttribute' => ['ignoreCase' => true, 'someValue']
@@ -328,7 +333,7 @@ class AttributeLimitTest extends TestCase
      * Test for attribute value matching ignore case
      * @return void
      */
-    public function testMatchAttributeValuesIgnoreCase()
+    public function testMatchAttributeValuesIgnoreCase(): void
     {
         $config = [
             'eduPersonAffiliation' => ['ignoreCase' => true, 'meMber']
@@ -370,10 +375,10 @@ class AttributeLimitTest extends TestCase
      * Test for attribute value matching
      * @return void
      */
-    public function testMatchAttributeValuesRegex()
+    public function testMatchAttributeValuesRegex(): void
     {
         // SSP Logger requires a configuration to be set.
-        \SimpleSAML\Configuration::loadFromArray([], '[ARRAY]', 'simplesaml');
+        Configuration::loadFromArray([], '[ARRAY]', 'simplesaml');
         $state = self::$request;
         $state['Attributes']['eduPersonEntitlement'] = [
             'urn:mace:example.terena.org:tcs:personal-user',
@@ -472,9 +477,9 @@ class AttributeLimitTest extends TestCase
      * Cannot be generated via config options.
      * @return void
      */
-    public function testMatchAttributeValuesNotArray()
+    public function testMatchAttributeValuesNotArray(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         $config = [
         ];
 
@@ -502,7 +507,7 @@ class AttributeLimitTest extends TestCase
      * Test attributes not intersecting
      * @return void
      */
-    public function testNoIntersection()
+    public function testNoIntersection(): void
     {
         $config = [
             'default' => true,
