@@ -1,7 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace SimpleSAML\Test\Module\core\Auth\Process;
 
+use Exception;
 use PHPUnit\Framework\TestCase;
 use SimpleSAML\Module\core\Auth\Process\AttributeValueMap;
 
@@ -17,7 +20,7 @@ class AttributeValueMapTest extends TestCase
      * @param array $request  The request state.
      * @return array  The state array after processing.
      */
-    private static function processFilter(array $config, array $request)
+    private static function processFilter(array $config, array $request): array
     {
         $filter = new AttributeValueMap($config, null);
         $filter->process($request);
@@ -32,7 +35,7 @@ class AttributeValueMapTest extends TestCase
      * @covers SimpleSAML\Module\core\Auth\Process\AttributeValueMap::process
      * @return void
      */
-    public function testBasic()
+    public function testBasic(): void
     {
         $config = [
             'sourceattribute' => 'memberOf',
@@ -64,7 +67,7 @@ class AttributeValueMapTest extends TestCase
      * @covers SimpleSAML\Module\core\Auth\Process\AttributeValueMap::process
      * @return void
      */
-    public function testNoDuplicates()
+    public function testNoDuplicates(): void
     {
         $config = [
             'sourceattribute' => 'memberOf',
@@ -97,7 +100,7 @@ class AttributeValueMapTest extends TestCase
      * @covers SimpleSAML\Module\core\Auth\Process\AttributeValueMap::process
      * @return void
      */
-    public function testReplace()
+    public function testReplace(): void
     {
         $config = [
             'sourceattribute' => 'memberOf',
@@ -131,7 +134,7 @@ class AttributeValueMapTest extends TestCase
      * @covers SimpleSAML\Module\core\Auth\Process\AttributeValueMap::process
      * @return void
      */
-    public function testKeep()
+    public function testKeep(): void
     {
         $config = [
             'sourceattribute' => 'memberOf',
@@ -165,7 +168,7 @@ class AttributeValueMapTest extends TestCase
      * @covers SimpleSAML\Module\core\Auth\Process\AttributeValueMap::process
      * @return void
      */
-    public function testUnknownFlag()
+    public function testUnknownFlag(): void
     {
         $config = [
             '%test',
@@ -196,9 +199,9 @@ class AttributeValueMapTest extends TestCase
      * @covers SimpleSAML\Module\core\Auth\Process\AttributeValueMap::process
      * @return void
      */
-    public function testMissingSourceAttribute()
+    public function testMissingSourceAttribute(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         $config = [
             'targetattribute' => 'affiliation',
             'values' => [
@@ -223,9 +226,9 @@ class AttributeValueMapTest extends TestCase
      * @covers SimpleSAML\Module\core\Auth\Process\AttributeValueMap::process
      * @return void
      */
-    public function testMissingTargetAttribute()
+    public function testMissingTargetAttribute(): void
     {
-        $this->expectException(\Exception::class);
+        $this->expectException(Exception::class);
         $config = [
             'sourceattribute' => 'memberOf',
             'values' => [
